% GETEDO : Get equivalent discrete-time system matrices
%          for time i from the edorp array pgqrav
%
%          [ni,ni1,mi,ldi,phi,gam,qi,ri,mc,vi,c,w,me]=getedo(pgqrav,i)
%
%	   input:
%          pgqrav : edorp array (see lqgrarv)
%          i      : time index 1,2,..,N (N=N+1)
%
%          output :
%          ni,ni1,mi,ldi
%          phi,gam,qi,ri,am,vi at time i
% 
function [ni,ni1,mi,ldi,phi,gam,qi,ri,mc,vi,c,w,me]=getedo(pgqrav,i);

if nargin~=2; error('  Two input arguments required'); end;
[nh,mh]=size(pgqrav);
if mh~=1; error(' First input argument must be a column vector'); end;

% Determine N (=N+1) and check i
N=pgqrav(1); if i<1 | i>N; error(' 1 <= i <= N violated'); end;

% Adjust i to N-1 if i==N :
% then only n(N) is important
if i==N; hN=1; i=N-1; else; hN=0; end;

% Determine the offset o(i)
oi=pgqrav(1+i);

% Determine n(i),n(i+1),m(i) and
oi=oi+1; ni=pgqrav(oi); oi=oi+1; ni1=pgqrav(oi);
oi=oi+1; mi=pgqrav(oi); oi=oi+1; ldi=pgqrav(oi);

% Extra offset to skip x0m,x0c if i==1
if i==1; oi=oi+ni+ni*ni; end;

% Obtain matrices
n=ni1; m=ni; nm=n*m;
phi=zeros(n,m); phi(:)=pgqrav(oi+1:oi+nm); oi=oi+nm;
n=ni1; m=mi; nm=n*m;
gam=zeros(n,m); gam(:)=pgqrav(oi+1:oi+nm); oi=oi+nm;
n=ni; m=ni; nm=n*m;
qi=zeros(n,m); qi(:)=pgqrav(oi+1:oi+nm); oi=oi+nm;
n=mi; m=mi; nm=n*m;
ri=zeros(n,m); ri(:)=pgqrav(oi+1:oi+nm); oi=oi+nm;
n=ni; m=mi; nm=n*m;
mc=zeros(n,m); mc(:)=pgqrav(oi+1:oi+nm); oi=oi+nm;
n=ni1; m=ni1; nm=n*m;
vi=zeros(n,m); vi(:)=pgqrav(oi+1:oi+nm); oi=oi+nm;
n=ldi; m=ni; nm=n*m;
c=zeros(n,m); c(:)=pgqrav(oi+1:oi+nm); oi=oi+nm;
n=ldi; m=ldi; nm=n*m;
w=zeros(n,m); w(:)=pgqrav(oi+1:oi+nm); oi=oi+nm;
n=ni1; m=ldi; nm=n*m;
me=zeros(n,m); me(:)=pgqrav(oi+1:oi+nm); oi=oi+nm;
if pgqrav(oi+1)~=ni1; error(' ni1 check error'); end;

% Adjust ni(N) if i was equal to N 
if hN==1; ni=ni1; end;
