function [Pcov,kal,xhat]=kmfmu(c,w,Pcov,xhat,y);
% KMFMU: Discrete-time Kalman filter measurement update.
%
%        [Pcov,kal,xhat]=kmfmu(c,w,Pcov,xhat,y)
%
%        Pcov:  Covariance matrix
%        kal:   Kalman gain
%        c:     Output matrix
%        w:     Output covariance matrix
%        y:     Measurement
%        xhat:  Estimate
%
%        L.G. Van Willigenburg, W.L. De Koning, 10-01-02.
%
[l,n]=size(c);
kal=Pcov*c'*inv(c*Pcov*c'+w);
ikh=eye(n)-kal*c;
Pcov=ikh*Pcov*ikh'+kal*w*kal';
if nargin==5
  xhat=ikh*xhat+kal*y;
else
  xhat=[];
end;
