function [a,b,v,q,r,xr,ur,d,n,m,c,w,l,H,G,x0]=lqgady(tim,pars)
% LQGADY: Function generates the matrix arrays a,v,b,c,w,q,r,xr,ur,d
%         which belong to a digital LQG problem for the time vector
%         tim. The matrix arrays are stored columnwise! See getmat.m!!
%
%         [a,b,q,r,xr,ur,d,n,m,c,w,l,h,G]=lqgady(tim,pars)
%         or
%         [c,w]=lqgady(tim,pars)
%
%         Output:
%         a: Matrix array stored columnwise.
%         the same for b,v,q,r,xr,ur,d. See getmat.m.
%
%         n:	dimension state vector
%         m:	dimension control vector
%
%         c:  output matrix at final time; c(tf), tf last element of tim.
%         w:  covariance matrix of c(tf)
%         l:  dimension of the output
%
%         h:  matrix representing the quadratic cost at the final time
%         G:  matrix representing the initial state covariance
%         x0: Initial (extended) state
%
%         See also, lqgatv.m, lqgaob.m, lqgare.m, lqgarv.m
%
%         L.G. Van Willigenburg, W.L. De Koning, 10-01-02.
%
if nargout>16;error('lqgady should have nomore than 16 output arguments');end;
if nargin>2;error('lqgady should have 1 or 2 input arguments');end;
[n,m]=size(tim);if n~=1;error('argument should be a row vector');end;
tis=tim(1);tif=tim(m);one=ones(1,m);
%a=[-2*one-3*sin(0.5*pi*tim);5*one;0*one;-4*one-5*cos(0.5*pi*tim)];
a=[0.3*one+0.2*sin(0.5*pi*tim);5*one;0*one;0.5*one+0.4*cos(0.5*pi*tim)];
b=[sin(3*tim);-1*one;1*one;cos(3*tim)];
q=[2*one+sin(2*tim);0.5*one;0.5*one;2*one+sin(2*tim)];
r=0.01*[2*one+cos(2*tim);-0.5*one;-0.5*one;2*one+cos(2*tim)];
v=0.05*[1.5*one+cos(2*pi*tim);0.2*one;0.2*one;1.3*one+sin(pi*tim)];
%v=0*v;
d=[0*one;0*one];
xr=[sin(tim);cos(tim)]; xr=0*xr;
ur=[0*one;0*one];
if exist('pars')==1
  if pars(1,1)==1; ticw=tis; else; ticw=tif; end
else
  ticw=tif;
end
c=[-sin(2*pi*ticw) 1;-2 3*cos(pi*ticw)];
w=0.5*[1.4+cos(pi*ticw) 0.3;0.3 2+cos(4*pi*ticw)];
n=2;m=2;l=2;
H=[10 -1;-1 10];
G=0.1*[2 1;1 3];

% Initial (extended) state
x0=[1;1;0];
