function [a,b,v,q,r,xr,ur,d,n,m,c,w,l,H,G,x0]=lqgady1(tim,pars)
% LQGADY1: Function generates the matrix arrays a,v,b,c,w,q,r,xr,ur,d
%         which belong to a digital LQG problem for the time vector
%         tim. The matrix arrays are stored columnwise! See getmat.m!!
%
%         [a,b,q,r,xr,ur,d,n,m,c,w,l,h,G]=lqgady(tim,pars)
%         or
%         [c,w]=lqgady(tim,pars)
%
%         Output:
%         a: Matrix array stored columnwise.
%         the same for b,v,q,r,xr,ur,d. See getmat.m.
%
%         n:	dimension state vector
%         m:	dimension control vector
%
%         c:  output matrix at final time; c(tf), tf last element of tim.
%         w:  covariance matrix of c(tf)
%         l:  dimension of the output
%
%         h:  matrix representing the quadratic cost at the final time
%         G:  matrix representing the initial state covariance
%         x0: Initial (extended) state
%
%         See also, lqgatv.m, lqgaob.m, lqgare.m, lqgarv.m
%
%         L.G. Van Willigenburg, W.L. De Koning, 10-01-02.
%
if nargout>16;error('lqgady should have nomore than 16 output arguments');end;
if nargin>2;error('lqgady should have 1 or 2 input arguments');end;
[n,m]=size(tim);if n~=1;error('argument should be a row vector');end;
tis=tim(1);tif=tim(m);one=ones(1,m);

a=[0.01*one;one;-one;0.01*one];
b=[0*one;1*one];
q=[1*one;0*one;0*one;1*one];
r=[0*one];
v=[1*one;0*one;0*one;1*one];

d=[]; xr=[]; ur=[];

c=[1 0];
w=0.01;
H=[0 0; 0 0];
G=[0 0; 0 0];
n=2;m=1;l=1;
% Initial (extended) state
x0=[10;10];
