% LQGAR:   Example of asynchronous reduced-order LQG compensation
%          uses : lqgady.m edortv.m lqgrarv.m lqgarea.m
%                 pgcvchk.m getedo.m getcob.m getxgh.m
%                 dprotva.m/dprotvla.m
%          additional : getfkl.m to get compensator matrices

  clear; randn('seed',0); rand('seed',0);

% Columnvector determining the controls and observations
  Msamp=[[0.0;1;1;2; 0;1;2],...
         [0.2;0;1;2; 1;1;2],...
         [0.5;2;1;2; 2;1;2],...
         [0.8;1;2;1; 0;1;2],...
         [0.9;0;1;2; 1;2;1],...
         [1.4;0;1;2; 2;1;2],...
         [1.5;1;1;2; 0;1;2],...
         [2.1;0;1;2; 0;1;2]];

% Transformation into equivalent discrete-time problem
  [lqgarr,gkr]=lqgrarv('lqgady',Msamp);

% Specification of dimensions compensator state  
  nc=[3 4 2 3 4 4 3 2];

% Solution of equivalent discrete-time problem using the SDOPE
% obtain compensator matrices at time i using function getfkl
  opt(1)=1e-8; opt(4)=50; opt(5)=0.5; opt(5)=1e-2; opt(6)=3; [xfkl,sigp,sigs,ptt,stt,pht,sht]=dprotva(lqgarr,nc,opt);
  disp(' '); disp('  Example from previous paper: full-order compensation');
  disp(['  nc   =  ' num2str(nc)]);
  disp(['  costs=' num2str(sigp+gkr) ', ' num2str(sigs+gkr)]);
  pause(1);

% Specification of dimensions compensator state  
  nc=[1 1 2 2 1 1 1 0];

% Solution of equivalent discrete-time problem using the SDOPE
% obtain compensator matrices at time i using function getfkl
  opt(1)=1e-8; opt(4)=50; opt(5)=0.5; opt(6)=1; [xfklp1,sigp1,sigs1,ptt,stt,pht,sht]=dprotva(lqgarr,nc,opt);
  disp(' '); disp('  Example computed with software from current paper: reduced-order compensation');
  disp(['  nc   =  ' num2str(nc)]);
  disp(['  costs=' num2str(sigp1+gkr) ', ' num2str(sigs1+gkr)]);
  pause(1);
  
  % Specification of dimensions compensator state  
  nc=[1 1 1 2 1 1 1 0];
  [xfklp2,sigp2,sigs2,ptt,stt,pht,sht]=dprotva(lqgarr,nc,opt);
  disp(['  nc   =  ' num2str(nc)]);
  disp(['  costs=' num2str(sigp2+gkr) ', ' num2str(sigs2+gkr)]);
  pause(1);

% Specification of dimensions compensator state  
  nc=[1 1 1 1 1 1 1 0];
  [xfklp3,sigp3,sigs3,ptt,stt,pht,sht]=dprotva(lqgarr,nc,opt);
  disp(['  nc   =  ' num2str(nc)]);
  disp(['  costs=' num2str(sigp3+gkr) ', ' num2str(sigs3+gkr)]);
  pause(1);

% Display the optimal compensator matrices
  disp(' ');disp('  Optimal compensator 1')
  getfkl(xfklp1);

  disp(' ');disp('  Optimal compensator 2')
  getfkl(xfklp2);

  disp(' ');disp('  Optimal compensator 3')
  getfkl(xfklp3);
