% LQGAR1:  Example of asynchronous reduced-order LQG compensation
%          uses : lqgady.m edortv.m lqgrarv.m lqgarea.m
%                 pgcvchk.m getedo.m getcob.m getxgh.m
%                 dprotva.m/dprotvla.m
%          additional : getfkl.m to get compensator matrices

  clear; randn('seed',0); rand('seed',0);

  N=20; ts=20*pi/N; dT=0.0*ts; delT=0.25*ts;
  sc=[1;1;0;1]; so=[0;1;1;1]; Msamp=[0;1;1;1;1]; i=1;
  for j=1:N/2-1
    Msamp=[Msamp [i*(ts+dT)-delT; so] [i*(ts+dT)+delT; sc] ...
                 [(i+1)*(ts+dT)-delT; sc] [(i+1)*(ts+dT)+delT; so]];
    i=i+2;
  end
  Msamp=[Msamp [i*(ts+dT)-delT; so] [i*(ts+dT)+delT; sc]];
  Msamp=[Msamp [(i+1)*(ts+dT); sc]]; [nh,N]=size(Msamp);

% Transformation into equivalent discrete-time problem
  [lqgarr,gkr]=lqgrarv('lqgady1',Msamp);

% Specification of dimensions compensator state  
  nc=3*ones(1,N);

% Solution of equivalent discrete-time problem using the SDOPE
% obtain compensator matrices at time i using function getfkl
  opt(1)=1e-8; opt(4)=50; opt(5)=1e-2; opt(6)=1; [xfkl,sigp,sigs,ptt,stt,pht,sht]=dprotva(lqgarr,nc,opt);
  disp(' '); disp('  Full-order compensation');
%  disp(['  nc   =  ' num2str(nc)]);
  disp(['  costs=' num2str(sigp+gkr) ', ' num2str(sigs+gkr)]);
  pause(1);

% Specification of dimensions compensator state  
  nc=2*ones(1,N);

% Solution of equivalent discrete-time problem using the SDOPE
% obtain compensator matrices at time i using function getfkl
  opt(1)=1e-8; opt(4)=50; opt(5)=0.5; opt(6)=1; [xfklp1,sigp1,sigs1,ptt,stt,pht,sht]=dprotva(lqgarr,nc,opt);
  disp(' '); disp('  Reduced-order compensation');
%  disp(['  nc   =  ' num2str(nc)]);
  disp(['  costs=' num2str(sigp1+gkr) ', ' num2str(sigs1+gkr)]);
  pause(1);
  
% Specification of dimensions compensator state  
  nc=1*ones(1,N);

  opt(1)=1e-8; opt(4)=50; opt(5)=0.5; opt(6)=1; 
% [xfklp2,sigp2,sigs2,ppt2,sst2]=dprotvla(lqgarr,nc,opt);
  opt(8)=1e-6; [xfklp2,sigp2,sigs2,ppt2,sst2]=dprotvla(lqgarr,nc,opt);
  disp(' '); disp('  Reduced-order compensation');
%  disp(['  nc   =  ' num2str(nc)]);
  disp(['  costs=' num2str(sigp2+gkr) ', ' num2str(sigs2+gkr)]);
  pause(1);

% obtain compensator matrices at time i using function getfkl
% 
% Display the optimal compensator matrices
%   disp(' ');disp('  Optimal compensator 1')
%   getfkl(xfkl);
% 
%   disp(' ');disp('  Optimal compensator 2')
%   getfkl(xfklp1);
% 
%   disp(' ');disp('  Optimal compensator 3')
%   getfkl(xfklp2);
