% LQGAR2:  Example of asynchronous reduced-order LQG compensation
%          uses : lqgady.m edortv.m lqgrarv.m lqgarea.m
%                 pgcvchk.m getedo.m getcob.m getxgh.m
%                 dprotva.m/dprotvla.m
%          additional : getfkl.m to get compensator matrices

  clear; randn('seed',0); rand('seed',0);

  N=20; Msamp=[[0:pi:N*pi]; ones(4,21)];

  % Transformation into equivalent discrete-time problem
  [lqgarr,gkr]=lqgrarv('lqgady1',Msamp);

% Specification of dimensions compensator state  
  nc=2*ones(1,N);

% Solution of equivalent discrete-time problem using the SDOPE
% obtain compensator matrices at time i using function getfkl
  opt(1)=1e-8; opt(4)=50; opt(5)=1e-2; opt(6)=1; [xfkl,sigp,sigs,ptt,stt,pht,sht]=dprotva(lqgarr,nc,opt);
  disp(' '); disp('  Full-order compensation');
%  disp(['  nc   =  ' num2str(nc)]);
  disp(['  costs=' num2str(sigp+gkr) ', ' num2str(sigs+gkr)]);
  pause(1);

% Specification of dimensions compensator state  
  nc=1*ones(1,N);

% Solution of equivalent discrete-time problem using the SDOPE
% obtain compensator matrices at time i using function getfkl
  opt(1)=1e-8; opt(4)=50; opt(5)=0.5; opt(6)=1; [xfklp1,sigp1,sigs1,ptt,stt,pht,sht]=dprotva(lqgarr,nc,opt);
  disp(' '); disp('  Reduced-order compensation');
%  disp(['  nc   =  ' num2str(nc)]);
  disp(['  costs=' num2str(sigp1+gkr) ', ' num2str(sigs1+gkr)]);
  pause(1);
  
% Display the optimal compensator matrices
%   disp(' ');disp('  Optimal compensator 1')
%   getfkl(xfkl);
% 
%   disp(' ');disp('  Optimal compensator 2')
%   getfkl(xfklp1);
% 
%   disp(' ');disp('  Optimal compensator 3')
%   getfkl(xfklp2);
